A function that allows you to create the palettes of fonctionr.
Usage
official_pal(
inst,
n,
direction = 1,
desaturate = 0,
lighten = 0,
darken = 0,
show_pal = FALSE,
font = "Gotham Narrow",
list_pal_names = FALSE
)Arguments
- inst
Name of the palette.
- n
Number of colors.
- direction
Direction of the palette color. Default is
1. The opposite direction is-1.- desaturate
Numeric specifying the amount of desaturation where
1corresponds to complete desaturation,0to no desaturation, and values in between to partial desaturation.- lighten
Numeric specifying the amount of lightening. Negative numbers cause darkening.
- darken
Numeric specifying the amount of lightening. Negative numbers cause lightening.
- show_pal
TRUEto display a graph representing the specified color palette.- font
Font used in the graphic. See
load_and_active_fonts()for available fonts.- list_pal_names
TRUEto generate a vector with palette names.